@@ -49,7 +49,7 @@ public:
     ~KEducaView();
     /** Open url */
     bool openURL( const KURL &url);
-    FileRead const *getKeducaFile() const {return _keducaFile; };
+    FileRead const *getKeducaFile() const {return _keducaFile; }
 
 private:
 
