@@ -1,4 +1,4 @@
-/**
+/*
  This file is part of Kig, a KDE program for Interactive Geometry...
  Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
 
@@ -14,9 +14,9 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
-**/
+*/
 
 #ifndef KIG_MISC_COORDINATE_SYSTEM_H
 #define KIG_MISC_COORDINATE_SYSTEM_H
@@ -33,6 +33,10 @@ class QString;
 class QStringList;
 class QWidget;
 
+/**
+ * a factory to build a CoordinateSystem and a small handle to the
+ * existant CoordinateSystem's...
+ */
 class CoordinateSystemFactory
 {
 public:
@@ -44,14 +48,16 @@ public:
   static CoordinateSystem* build( const char* type );
 };
 
-// a CoordinateSystem is what the user sees: it is kept by KigPart to
-// show the user a grid, and to show the coordinates of points... it
-// allows for weird CoordinateSystem's like homogeneous or
-// projective...
-// internally, it does nothing, it could almost have been an ordinary
-// Object..., mapping coordinates from and to the screen to and from
-// the internal coordinates is done elsewhere ( KigPainter and
-// KigWidget... )
+/**
+ * a CoordinateSystem is what the user sees: it is kept by KigPart to
+ * show the user a grid, and to show the coordinates of points... it
+ * allows for weird CoordinateSystem's like homogeneous or
+ * projective...
+ * internally, it does nothing, it could almost have been an ordinary
+ * Object..., mapping coordinates from and to the screen to and from
+ * the internal coordinates is done elsewhere ( KigPainter and
+ * KigWidget... )
+ */
 class CoordinateSystem
   : public Qt
 {
@@ -59,10 +65,6 @@ public:
   CoordinateSystem();
   virtual ~CoordinateSystem();
 
-  const Coordinate getCoordFromUser( const QString& caption, const QString& label,
-                                     const KigDocument& doc, QWidget* parent, bool* ok = 0,
-                                     const Coordinate* value = 0 ) const;
-
   virtual QString fromScreen ( const Coordinate& pt, const KigDocument& w ) const = 0;
   /**
    * This returns a notice to say in which format coordinates should
@@ -71,6 +73,11 @@ public:
    * x is the x coordinate, and y is the y coordinate." );
    */
   virtual QString coordinateFormatNotice() const = 0;
+  /**
+   * Like \ref coordinateFormatNotice(), but with HTML tags useful to
+   * have a rich text...
+   */
+  virtual QString coordinateFormatNoticeMarkup() const = 0;
   virtual Coordinate toScreen (const QString& pt, bool& ok) const = 0;
   virtual void drawGrid ( KigPainter& p, bool showgrid = true,
                           bool showaxes = true ) const = 0;
@@ -90,6 +97,7 @@ public:
   ~EuclideanCoords();
   QString fromScreen( const Coordinate& pt, const KigDocument& w ) const;
   QString coordinateFormatNotice() const;
+  QString coordinateFormatNoticeMarkup() const;
   Coordinate toScreen (const QString& pt, bool& ok) const;
   void drawGrid ( KigPainter& p, bool showgrid = true,
                   bool showaxes = true ) const;
@@ -111,6 +119,7 @@ public:
   ~PolarCoords();
   QString fromScreen( const Coordinate& pt, const KigDocument& w ) const;
   QString coordinateFormatNotice() const;
+  QString coordinateFormatNoticeMarkup() const;
   Coordinate toScreen (const QString& pt, bool& ok) const;
   void drawGrid ( KigPainter& p, bool showgrid = true,
                   bool showaxes = true ) const;
