@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "polygon_type.h"
 
@@ -164,6 +164,7 @@ ObjectImp* PolygonBNPType::calc( const Args& parents, const KigDocument& ) const
   for ( uint i = 0; i < count; ++i )
   {
     npoints++;
+    if ( ! parents[i]->inherits( PointImp::stype() ) ) return new InvalidImp;
     Coordinate point = static_cast<const PointImp*>( parents[i] )->coordinate();
     centerofmassn += point;
     points.push_back( point );
@@ -283,12 +284,11 @@ const PolygonBCVType* PolygonBCVType::instance()
 ObjectImp* PolygonBCVType::calc( const Args& parents, const KigDocument& ) const
 {
   if ( parents.size() < 3 || parents.size() > 4 ) return new InvalidImp;
-  for ( uint i = 0; i < 2; ++i )
-  {
-    if ( ! parents[0]->inherits( PointImp::stype() ) ) return new InvalidImp;
-  }
 
-  if ( ! parents[2]->inherits( IntImp::stype() ) ) return new InvalidImp;
+  if ( ( ! parents[0]->inherits( PointImp::stype() ) ) ||
+       ( ! parents[1]->inherits( PointImp::stype() ) ) ||
+       ( ! parents[2]->inherits( IntImp::stype() ) ) )
+    return new InvalidImp;
 
   const Coordinate center = 
         static_cast<const PointImp*>( parents[0] )->coordinate();
