@@ -15,7 +15,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
 **/
 
@@ -803,8 +803,8 @@ void Learn::qnew() // new quiz kanji
 	for (; sIt.current(); ++sIt)
 		scores.insert(sIt.current());
 
-	std::multiset<const QListViewItem*>::iterator it = scores.begin();
-	std::multiset<const QListViewItem*>::iterator tmp = scores.begin();
+	std::multiset<const QListViewItem*, scoreCompare>::iterator it = scores.begin();
+	std::multiset<const QListViewItem*, scoreCompare>::iterator tmp = scores.begin();
 
 	int i;
 	for (i = 2; i <= max; ++it)
