@@ -32,7 +32,8 @@ bool updateStatus();
 private:
 KStars *ksw;
 QTimer *seqTimer;
-INDIStdDevice *stdDev;
+INDIStdDevice *stdDevCCD;
+INDIStdDevice *stdDevFilter;
 
 bool	active;
 bool	ISOStamp;
@@ -41,18 +42,29 @@ int	seqTotalCount;
 int	seqCurrentCount;
 int	seqDelay;
 int     retries;
-int     lastItem;
-QString currentDevice;
+int     lastCCD;
+int     lastFilter;
+QString currentCCD;
+QString currentFilter;
 
-bool	verifyDeviceIntegrity();
+bool	verifyCCDIntegrity();
+bool    verifyFilterIntegrity();
 void    resetButtons();
+void    selectFilter();
 
 public slots:
+ bool setupCCDs();
+ bool setupFilters();
+ void newCCD();
+ void newFilter();
+
  void startSequence();
  void stopSequence();
  void captureImage();
+ void prepareCapture();
  void newFITS(QString deviceLabel);
- void checkDevice(const QString & deviceLabel);
+ void checkCCD(int CCDNum);
+ void updateFilterCombo(int filterNum);
 
 };
 
