@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #endif
 
@@ -105,6 +105,17 @@ extern void IDDefLight (const ILightVectorProperty *l, const char *msg, ...)
 #endif
 ;
 
+/** \brief Tell client to create a BLOB vector property.
+    \param b pointer to the vector BLOB property to be defined.
+    \param msg message in printf style to send to the client. May be NULL.
+ */
+extern void IDDefBLOB (const IBLOBVectorProperty *b, const char *msg, ...)
+#ifdef __GNUC__
+    __attribute__ ( ( format( printf, 2, 3 ) ) )
+#endif
+;
+
+
 /*@}*/
 
 /**
@@ -152,6 +163,16 @@ extern void IDSetLight (const ILightVectorProperty *l, const char *msg, ...)
 #endif
 ;
 
+/** \brief Tell client to update an existing BLOB vector property.
+    \param b pointer to the vector BLOB property.
+    \param msg message in printf style to send to the client. May be NULL.
+ */
+extern void IDSetBLOB (const IBLOBVectorProperty *b, const char *msg, ...)
+#ifdef __GNUC__
+    __attribute__ ( ( format( printf, 2, 3 ) ) )
+#endif
+;
+
 /*@}*/
 
 
@@ -311,6 +332,7 @@ extern void IUResetSwitches(const ISwitchVectorProperty *svp);
 * \param states the states of the new ISwitch members.
 * \param names the names of the ISwtich members to update.
 * \param n the number of ISwitch members to update.
+* \return 0 if update successful, -1 otherwise.
 */
 extern int IUUpdateSwitches(ISwitchVectorProperty *svp, ISState *states, char *names[], int n);
 
@@ -320,11 +342,12 @@ extern int IUUpdateSwitches(ISwitchVectorProperty *svp, ISState *states, char *n
 * \param values the states of the new INumber members.
 * \param names the names of the INumber members to update.
 * \param n the number of INumber members to update.
+* \return 0 if update successful, -1 otherwise. Update will fail if values are out of scope, or in case of property name mismatch.
 */
 extern int IUUpdateNumbers(INumberVectorProperty *nvp, double values[], char *names[], int n);
 
 /** \brief Function to update the min and max elements of a number in the client
-    \param tp pointer to an INumberVectorProperty.
+    \param nvp pointer to an INumberVectorProperty.
  */
 extern void IUUpdateMinMax(INumberVectorProperty *nvp);
 
@@ -334,6 +357,77 @@ extern void IUUpdateMinMax(INumberVectorProperty *nvp);
 */
 extern void IUSaveText (IText *tp, const char *newtext);
 
+/** \brief Assign attributes for a switch property. The switch's auxilary elements will be set to NULL.
+    \param sp pointer a switch property to fill
+    \param name the switch name
+    \param label the switch label
+    \param s the switch state (ISS_ON or ISS_OFF)
+*/
+extern void fillSwitch(ISwitch *sp, const char *name, const char * label, ISState s);
+
+/** \brief Assign attributes for a number property. The number's auxilary elements will be set to NULL.
+    \param np pointer a number property to fill
+    \param name the number name
+    \param label the number label
+    \param format the number format in printf style (e.g. "%02d")
+    \param min  the minimum possible value
+    \param max the maximum possible value
+    \param step the step used to climb from minimum value to maximum value
+    \param value the number's current value
+*/
+extern void fillNumber(INumber *np, const char *name, const char * label, const char *format, double min, double max, double step, double value);
+
+/** \brief Assign attributes for a text property. The text's auxilary elements will be set to NULL.
+    \param tp pointer a text property to fill
+    \param name the text name
+    \param label the text label
+    \param initialText the initial text
+*/
+extern void fillText(IText *tp, const char *name, const char * label, const char *initialText);
+
+/** \brief Assign attributes for a switch vector property. The vector's auxilary elements will be set to NULL.
+    \param svp pointer a switch vector property to fill
+    \param sp pointer to an array of switches
+    \param nsp the dimension of sp
+    \param dev the device name this vector property belongs to
+    \param name the vector property name
+    \param label the vector property label
+    \param group the vector property group
+    \param p the vector property permission
+    \param r the switches behavior
+    \param timeout vector property timeout in seconds 
+    \param s the vector property initial state.
+*/
+extern void fillSwitchVector(ISwitchVectorProperty *svp, ISwitch *sp, int nsp, const char * dev, const char *name, const char *label, const char *group, IPerm p, ISRule r, double timeout, IPState s);
+
+/** \brief Assign attributes for a number vector property. The vector's auxilary elements will be set to NULL.
+    \param nvp pointer a number vector property to fill
+    \param np pointer to an array of numbers
+    \param nnp the dimension of np
+    \param dev the device name this vector property belongs to
+    \param name the vector property name
+    \param label the vector property label
+    \param group the vector property group
+    \param p the vector property permission
+    \param timeout vector property timeout in seconds 
+    \param s the vector property initial state.
+*/
+extern void fillNumberVector(INumberVectorProperty *nvp, INumber *np, int nnp, const char * dev, const char *name, const char *label, const char* group, IPerm p, double timeout, IPState s);
+
+/** \brief Assign attributes for a text vector property. The vector's auxilary elements will be set to NULL.
+    \param tvp pointer a text vector property to fill
+    \param tp pointer to an array of texts
+    \param ntp the dimension of tp
+    \param dev the device name this vector property belongs to
+    \param name the vector property name
+    \param label the vector property label
+    \param group the vector property group
+    \param p the vector property permission
+    \param timeout vector property timeout in seconds 
+    \param s the vector property initial state.
+*/
+extern void fillTextVector(ITextVectorProperty *tvp, IText *tp, int ntp, const char * dev, const char *name, const char *label, const char* group, IPerm p, double timeout, IPState s);
+
 /*@}*/
 
 /*******************************************************************************
@@ -393,6 +487,21 @@ extern void ISNewNumber (const char *dev, const char *name, double *doubles,
 extern void ISNewSwitch (const char *dev, const char *name, ISState *states,
     char *names[], int n); 
 
+/** \brief Update data of an existing blob vector property.
+    \param dev the name of the device.
+    \param name the name of the blob vector property to update.
+    \param sizes an array of blob sizes in bytes.
+    \param blobs the blob data array in bytes
+    \param formats Blob data format (e.g. fits.z).
+    \param names names of blob members to update. 
+    \param n the number of blobs to update.
+    \note You do not need to call this function, it is called by INDI when new blob values arrive from the client.
+          e.g. BLOB element with name names[0] has data located in blobs[0] with size sizes[0] and format formats[0].
+*/
+
+extern void ISNewBLOB (const char *dev, const char *name, int sizes[],
+    char *blobs[], char *formats[], char *names[], int n); 
+
 /*@}*/
 
 #ifdef __cplusplus
