@@ -52,7 +52,7 @@ void KStars::initActions() {
 			this, SLOT( newWindow() ), actionCollection(), "new_window");
 	new KAction(i18n("&Close Window"), "fileclose", KShortcut( "Ctrl+W"  ),
 			this, SLOT( closeWindow() ), actionCollection(), "close_window");
-	new KAction( i18n( "&Download Data..." ), "lknewstuff", KShortcut( "Ctrl+D" ),
+	new KAction( i18n( "&Download Data..." ), "knewstuff", KShortcut( "Ctrl+D" ),
 			this, SLOT( slotDownload() ), actionCollection(), "get_data" );
 	new KAction( i18n( "Open FITS..."), "fileopen", KShortcut( "Ctrl+O"), this, SLOT( slotOpenFITS()), actionCollection(), "open_file");
 	new KAction( i18n( "&Save Sky Image..." ), "fileexport", KShortcut( "Ctrl+I" ),
@@ -95,10 +95,6 @@ void KStars::initActions() {
 
 	new KAction( i18n( "Engage &Tracking" ), "decrypted", KShortcut( "Ctrl+T"  ),
 		this, SLOT( slotTrack() ), actionCollection(), "track_object" );
-	if ( Options::isTracking() ) {
-		actionCollection()->action("track_object")->setText( i18n( "Stop &Tracking" ) );
-		actionCollection()->action("track_object")->setIconSet( BarIcon( "encrypted" ) );
-	}
 
 	new KAction( i18n( "Set Focus &Manually..." ), KShortcut( "Ctrl+M" ),
 			this, SLOT( slotManualFocus() ),  actionCollection(), "manual_focus" );
@@ -112,7 +108,6 @@ void KStars::initActions() {
 		this, SLOT( slotSetZoom() ), actionCollection(), "zoom_set" );
 	actCoordSys = new ToggleAction( i18n("Horizontal &Coordinates"), i18n( "Equatorial &Coordinates" ),
 			Key_Space, this, SLOT( slotCoordSys() ), actionCollection(), "coordsys" );
-	if ( Options::useAltAz() ) actCoordSys->turnOff();
 	KStdAction::fullScreen( this, SLOT( slotFullScreen() ), actionCollection(), 0 );
 
 
@@ -126,79 +121,45 @@ void KStars::initActions() {
 	//Info Boxes option actions
 	KToggleAction *a = new KToggleAction(i18n( "Show the information boxes", "Show &Info Boxes"),
 			0, 0, 0, actionCollection(), "show_boxes");
-#if KDE_IS_VERSION( 3, 2, 90 )
-//	a->setCheckedState(i18n("Hide &Info Boxes"));
-#endif
 	a->setChecked( Options::showInfoBoxes() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(setVisible(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
-	infoBoxes()->setVisible( Options::showInfoBoxes() );
 
 	a = new KToggleAction(i18n( "Show time-related info box", "Show &Time Box"),
 			0, 0, 0, actionCollection(), "show_time_box");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide &Time Box"));
-#endif
-	a->setChecked( Options::showTimeBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showTimeBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 	a = new KToggleAction(i18n( "Show focus-related info box", "Show &Focus Box"),
 			0, 0, 0, actionCollection(), "show_focus_box");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide &Focus Box"));
-#endif
-	a->setChecked( Options::showFocusBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showFocusBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 	a = new KToggleAction(i18n( "Show location-related info box", "Show &Location Box"),
 			0, 0, 0, actionCollection(), "show_location_box");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide &Location Box"));
-#endif
-	a->setChecked( Options::showGeoBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showGeoBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 //Toolbar view options
 	a = new KToggleAction(i18n( "Show Main Toolbar" ),
 			0, 0, 0, actionCollection(), "show_mainToolBar");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide Main Toolbar"));
-#endif
-	a->setChecked( Options::showMainToolBar() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 	a = new KToggleAction(i18n( "Show View Toolbar" ),
 			0, 0, 0, actionCollection(), "show_viewToolBar");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide View Toolbar"));
-#endif
-	a->setChecked( Options::showViewToolBar() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 //Statusbar view options
 	a = new KToggleAction(i18n( "Show Statusbar" ),
 			0, 0, 0, actionCollection(), "show_statusBar");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide Statusbar"));
-#endif
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
-	a->setChecked( Options::showStatusBar() );
+
 	a = new KToggleAction(i18n( "Show Az/Alt Field" ),
 			0, 0, 0, actionCollection(), "show_sbAzAlt");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide Az/Alt Field"));
-#endif
-	a->setChecked( Options::showAltAzField() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
+
 	a = new KToggleAction(i18n( "Show RA/Dec Field" ),
 			0, 0, 0, actionCollection(), "show_sbRADec");
-#if KDE_IS_VERSION( 3, 2, 90 )
-	//a->setCheckedState(i18n("Hide RA/Dec Field"));
-#endif
-	a->setChecked( Options::showRADecField() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 //Color scheme actions.  These are added to the "colorschemes" KActionMenu.
@@ -208,10 +169,6 @@ void KStars::initActions() {
 	addColorMenuItem( i18n( "&Night Vision" ), "cs_night" );
 	addColorMenuItem( i18n( "&Moonless Night" ), "cs_moonless-night" );
 
-//	colorActionMenu->insert( new KAction( i18n( "&Default" ), 0, this, SLOT( slotColorScheme() ), actionCollection(), "cs_default" ) );
-//	colorActionMenu->insert( new KAction( i18n( "&Star Chart" ), 0, this, SLOT( slotColorScheme() ), actionCollection(), "cs_chart" ) );
-//	colorActionMenu->insert( new KAction( i18n( "&Night Vision" ), 0, this, SLOT( slotColorScheme() ), actionCollection(), "cs_night" ) );
-
 //Add any user-defined color schemes:
 	QFile file;
 	QString line, schemeName, filename;
@@ -225,9 +182,6 @@ void KStars::initActions() {
 			//I call it filename here, but it's used as the name of the action!
 			filename = "cs_" + line.mid( line.find( ':' ) +1, line.find( '.' ) - line.find( ':' ) - 1 );
 			addColorMenuItem( i18n( schemeName.local8Bit() ), filename.local8Bit() );
-
-//			colorActionMenu->insert( new KAction( i18n( schemeName.local8Bit() ), 0,
-//					this, SLOT( slotColorScheme() ), actionCollection(), filename.local8Bit() ) );
 		}
 		file.close();
 	}
@@ -236,31 +190,21 @@ void KStars::initActions() {
 	fovActionMenu = new KActionMenu( i18n( "&FOV Symbols" ), actionCollection(), "fovsymbols" );
 	initFOV();
 
-	//use custom icon earth.png for the geoLocator icon.  If it is not installed
-  //for some reason, use standard icon gohome.png instead.
-	QFile tempFile;
-	if (KSUtils::openDataFile( tempFile, "earth.png" ) ) {
-		tmpAction = new KAction( i18n( "Set Geographic Location..." ),
-				tempFile.name(), KShortcut( "Ctrl+G"  ),
-				this, SLOT( slotGeoLocator() ), actionCollection(), "geolocation" );
-		tmpAction->setToolTip( i18n( "Geographic location" ) );
-		tempFile.close();
-	} else {
-		new KAction( i18n( "Location on Earth", "&Geographic..." ), "gohome", KShortcut( "Ctrl+G"  ),
-				this, SLOT( slotGeoLocator() ), actionCollection(), "geolocation" );
-	}
+	new KAction( i18n( "Location on Earth", "&Geographic..." ), 
+			"kstars_geo", KShortcut( "Ctrl+G"  ), this, 
+			SLOT( slotGeoLocator() ), actionCollection(), "geolocation" );
 
 	KStdAction::preferences( this, SLOT( slotViewOps() ), actionCollection(), "configure" );
 
-	new KAction(i18n( "Startup Wizard..." ), 0, this, SLOT( slotWizard() ),
-		actionCollection(), "startwizard" );
+	new KAction(i18n( "Startup Wizard..." ), "wizard", KShortcut(), 
+			this, SLOT( slotWizard() ), actionCollection(), "startwizard" );
 
 //Tools Menu:
-        new KAction(i18n( "Calculator..."), KShortcut( "Ctrl+C"),
-                    this, SLOT( slotCalculator() ), actionCollection(), "astrocalculator");
+	new KAction(i18n( "Calculator..."), KShortcut( "Ctrl+C"),
+			this, SLOT( slotCalculator() ), actionCollection(), "astrocalculator");
 
-        new KAction(i18n( "Observing List..."), KShortcut( "Ctrl+L"),
-                    this, SLOT( slotObsList() ), actionCollection(), "obslist");
+	new KAction(i18n( "Observing List..."), KShortcut( "Ctrl+L"),
+			this, SLOT( slotObsList() ), actionCollection(), "obslist");
 
 	// enable action only if file was loaded and processed successfully.
 	if (!data()->VariableStarsList.isEmpty())
@@ -271,6 +215,9 @@ void KStars::initActions() {
 						this, SLOT( slotAVT() ), actionCollection(), "altitude_vs_time");
 	new KAction(i18n( "What's up Tonight..."), KShortcut("Ctrl+U"),
 						this, SLOT(slotWUT()), actionCollection(), "whats_up_tonight");
+//FIXME GLOSSARY
+//	new KAction(i18n( "Glossary..."), KShortcut("Ctrl+K"),
+//						this, SLOT(slotGlossary()), actionCollection(), "glossary");
 	new KAction(i18n( "Script Builder..."), KShortcut("Ctrl+B"),
 						this, SLOT(slotScriptBuilder()), actionCollection(), "scriptbuilder");
 	new KAction(i18n( "Solar System..."), KShortcut("Ctrl+Y"),
@@ -280,6 +227,7 @@ void KStars::initActions() {
 
 // devices Menu
 	new KAction(i18n("Telescope Wizard..."), 0, this, SLOT(slotTelescopeWizard()), actionCollection(), "telescope_wizard");
+	new KAction(i18n("Telescope Properties..."), 0, this, SLOT(slotTelescopeProperties()), actionCollection(), "telescope_properties");
 	new KAction(i18n("Device Manager..."), 0, this, SLOT(slotINDIDriver()), actionCollection(), "device_manager");
 	
 	tmpAction = new KAction(i18n("Capture Image Sequence..."), 0, this, SLOT(slotImageSequence()), actionCollection(), "capture_sequence");
@@ -305,124 +253,43 @@ void KStars::initActions() {
 //
 
 //show_stars:
-	if (KSUtils::openDataFile( tempFile, "show_stars.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Stars" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_stars" );
-		a->setChecked( Options::showStars() );
-		tempFile.close();
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Stars" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_stars" );
-		a->setChecked( Options::showStars() );
-	}
+	a = new KToggleAction( i18n( "Toggle Stars" ), "kstars_stars", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_stars" );
 
 //show_deepsky:
-	if (KSUtils::openDataFile( tempFile, "show_deepsky.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Deep Sky Objects" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_deepsky" );
-		a->setChecked( Options::showDeepSky() );
-		tempFile.close();
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Deep Sky Objects" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_deepsky" );
-		a->setChecked( Options::showDeepSky() );
-	}
+	a = new KToggleAction( i18n( "Toggle Deep Sky Objects" ), "kstars_deepsky", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_deepsky" );
 
 //show_planets:
-	if (KSUtils::openDataFile( tempFile, "show_planets.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Solar System" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_planets" );
-		a->setChecked( Options::showPlanets() );
-		tempFile.close();
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Solar System" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_planets" );
-		a->setChecked( Options::showPlanets() );
-	}
+	a = new KToggleAction( i18n( "Toggle Solar System" ), "kstars_planets", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_planets" );
 
 //show_clines:
-	if (KSUtils::openDataFile( tempFile, "show_clines.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Lines" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_clines" );
-		a->setChecked( Options::showCLines() );
-		tempFile.close();
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Lines" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_clines" );
-		a->setChecked( Options::showCLines() );
-	}
+	a = new KToggleAction( i18n( "Toggle Constellation Lines" ), "kstars_clines", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_clines" );
 
 //show_cnames:
-	if (KSUtils::openDataFile( tempFile, "show_cnames.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Names" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cnames" );
-		a->setChecked( Options::showCNames() );
-		tempFile.close();
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Lines" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cnames" );
-		a->setChecked( Options::showCNames() );
-	}
+	a = new KToggleAction( i18n( "Toggle Constellation Names" ), "kstars_cnames", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_cnames" );
 
 //show_cbound:
-	if (KSUtils::openDataFile( tempFile, "show_cbound.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Boundaries" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cbounds" );
-		a->setChecked( Options::showCBounds() );
-		tempFile.close();
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Boundaries" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cbounds" );
-		a->setChecked( Options::showCBounds() );
-	}
+	a = new KToggleAction( i18n( "Toggle Constellation Boundaries" ), "kstars_cbound", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_cbounds" );
 
 //show_mw:
-	if (KSUtils::openDataFile( tempFile, "show_mw.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Milky Way" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_mw" );
-		a->setChecked( Options::showMilkyWay() );
-		tempFile.close();
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Milky Way" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_mw" );
-		a->setChecked( Options::showMilkyWay() );
-	}
+	a = new KToggleAction( i18n( "Toggle Milky Way" ), "kstars_mw", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_mw" );
 
 //show_grid:
-	if (KSUtils::openDataFile( tempFile, "show_grid.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Coordinate Grid" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_grid" );
-		tempFile.close();
-		a->setChecked( Options::showGrid() );
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Coordinate Grid" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_grid" );
-		a->setChecked( Options::showGrid() );
-	}
+	a = new KToggleAction( i18n( "Toggle Coordinate Grid" ), "kstars_grid", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_grid" );
 
 //show_horizon:
-	if (KSUtils::openDataFile( tempFile, "show_horiz.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Ground" ),
-				tempFile.name(), 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_horizon" );
-		tempFile.close();
-		a->setChecked( Options::showGround() );
-	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Ground" ), "wizard", 0,
-				this, SLOT( slotViewToolBar() ), actionCollection(), "show_horizon" );
-		a->setChecked( Options::showGround() );
-	}
+	a = new KToggleAction( i18n( "Toggle Ground" ), "kstars_horizon", 
+		0, this, SLOT( slotViewToolBar() ), actionCollection(), "show_horizon" );
 	
-        if (Options::fitsSaveDirectory().isEmpty())
-            Options::setFitsSaveDirectory(QDir:: homeDirPath());
+	if (Options::fitsSaveDirectory().isEmpty())
+			Options::setFitsSaveDirectory(QDir:: homeDirPath());
 }
 
 void KStars::initFOV() {
@@ -540,7 +407,7 @@ void KStars::datainitFinished(bool worked) {
 		QString caption = i18n( "Initial Position is Below Horizon" );
 		QString message = i18n( "The initial position is below the horizon.\nWould you like to reset to the default position?" );
 		if ( KMessageBox::warningYesNo( this, message, caption,
-				KStdGuiItem::yes(), KStdGuiItem::no(), "dag_start_below_horiz" ) == KMessageBox::Yes ) {
+				i18n("Reset Position"), i18n("Do Not Reset"), "dag_start_below_horiz" ) == KMessageBox::Yes ) {
 			map()->setClickedObject( NULL );
 			map()->setFocusObject( NULL );
 			Options::setIsTracking( false );
@@ -555,6 +422,13 @@ void KStars::datainitFinished(bool worked) {
 		}
 	}
 
+	//Store focus coords in Options object before calling applyConfig()
+	Options::setFocusRA( map()->focus()->ra()->Hours() );
+	Options::setFocusDec( map()->focus()->dec()->Degrees() );
+
+	//Propagate Options values through the program
+	applyConfig();
+
 	//If there is a focusObject() and it is a SS body, add a temporary Trail to it.
 	if ( map()->focusObject() && map()->focusObject()->isSolarSystem()
 			&& Options::useAutoTrail() ) {
@@ -605,11 +479,6 @@ void KStars::privatedata::buildGUI() {
 	//text of each button shorter
 	ks->toolBar( "viewToolBar" )->setIconText( KToolBar::IconOnly );
 
-	//Initialize show/hide state of toolbars.
-	//These were in initActions, but they must appear after createGUI...
-	if ( !Options::showMainToolBar() ) ks->toolBar( "mainToolBar" )->hide();
-	if ( !Options::showViewToolBar() ) ks->toolBar( "viewToolBar" )->hide();
-
 	ks->TimeStep = new TimeStepBox( ks->toolBar() );
 	ks->toolBar()->insertWidget( 0, 6, ks->TimeStep, 15 );
 
@@ -623,6 +492,9 @@ void KStars::privatedata::buildGUI() {
 
 	ks->resize( Options::windowWidth(), Options::windowHeight() );
 
+	//Geographic location
+	ks->setGeoLocation( Options::cityName(), Options::provinceName(), Options::countryName() );
+
 	// initialize clock with current time/date or the date/time specified on the command line
 	KStarsDateTime startDate = KStarsDateTime::fromString( ks->StartDateString );
 	if ( startDate.isValid() )
