@@ -17,9 +17,6 @@
 
 #include "kfeedercontrol.h"
 
-#include <qstring.h>
-#include <qcstring.h>
-#include <qdatastream.h>
 #include <kapplication.h>
 #include <kstandarddirs.h>
 
