@@ -71,6 +71,7 @@ public:
     void sortByColumn_alpha(int index);
     void sortByColumn_index(int index);
     void slotSelectionChanged();
+    void slotCurrentChanged(int, int);
 
   protected slots:
     void menuTriggerTimeout();
@@ -79,8 +80,8 @@ public:
 
   protected:
     int current;
-    QWidget* beginEdit(int row, int col, bool replace);
-    void endEdit(int row, int col, bool accept, bool replace);
+    //QWidget* beginEdit(int row, int col, bool replace);
+    //void endEdit(int row, int col, bool accept, bool replace);
     void paintCell(QPainter *p, int row, int col, const QRect &cr, bool selected, const QColorGroup &cg);
     void setItem(int row, int col, QTableItem * item);
     QTableItem* item (int row, int col) const;
