@@ -44,7 +44,7 @@ class ExtDateTable;
  *
  * \image html kdatepicker.png "KDE Date Widget"
  *
- *     @version $Id: extdatepicker.h 501479 2006-01-23 03:20:46Z harris $
+ *     @version $Id: extdatepicker.h 650959 2007-04-05 22:29:28Z mueller $
  *     @author Tim Gilman, Mirko Boehm
  *
  * @short A date selection widget.
@@ -122,7 +122,7 @@ public:
    * widget.
    * @since 3.2
    */
-  ExtDateTable *dateTable() const { return table; };
+  ExtDateTable *dateTable() const { return table; }
 
   /**
    * Sets the font size of the widgets elements.
